@@ -6,7 +6,7 @@ use Log::Any '$log';
 use Moo;
 extends 'Org::Element';
 
-our $VERSION = '0.29'; # VERSION
+our $VERSION = '0.30'; # VERSION
 
 has level => (is => 'rw');
 has title => (is => 'rw');
@@ -194,20 +194,26 @@ sub demote_branch {
     }
 }
 
+sub get_drawer {
+	my $self = shift;
+	my $wanted_drawer_name = shift || "PROPERTIES";
+
+	for my $d (@{$self->children||[]}) {
+        $log->tracef("seeking $wanted_drawer_name drawer in child: %s (%s)", $d->as_string, ref($d));
+		next unless ($d->isa('Org::Element::Drawer')
+					 && $d->name eq $wanted_drawer_name
+					 && $d->properties);
+		return $d;
+	}
+}
+
 sub get_property {
     my ($self, $name, $search_parent) = @_;
     #$log->tracef("-> get_property(%s, search_par=%s)", $name, $search_parent);
     my $p = $self->parent;
-    my $c = $self->children;
 
-    if ($c) {
-        for my $d (@$c) {
-        $log->tracef("searching in child: %s (%s)", $d->as_string, ref($d));
-            next unless $d->isa('Org::Element::Drawer')
-                && $d->name eq 'PROPERTIES' && $d->properties;
-            return $d->properties->{$name} if defined $d->properties->{$name};
-        }
-    }
+	my $pd = $self->get_drawer("PROPERTIES");
+	return $pd->properties->{$name} if ($pd and defined $pd->properties->{$name});
 
     if ($p && $search_parent) {
         next unless $p->isa('Org::Element::Headline');
@@ -231,7 +237,7 @@ Org::Element::Headline - Represent Org headline
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 DESCRIPTION
 
@@ -347,7 +353,7 @@ Does the opposite of promote_branch().
 
 =head2 $el->get_property($name, $search_parent) => VALUE
 
-Search for property named $name in the properties drawer. If $search_parent is
+Search for property named $name in the PROPERTIES drawer. If $search_parent is
 set to true (default is false), will also search in upper-level properties
 (useful for searching for inherited property, like foo_ALL). Return undef if
 property cannot be found.
@@ -355,6 +361,11 @@ property cannot be found.
 Regardless of $search_parent setting, file-wide properties will be consulted if
 property is not found in the headline's properties drawer.
 
+=head2 $el->get_drawer([$drawer_name]) => VALUE
+
+Return an entire drawer as an Org::Element::Drawer object. By default, return the
+PROPERTIES drawer. If you want LOGBOOK or some other drawer, ask for it by name.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
